You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@tuscany.apache.org by jb...@apache.org on 2007/02/02 19:24:38 UTC

svn commit: r502683 - /incubator/tuscany/java/spec/sca-api-r1.0/src/main/java/org/osoa/sca/RequestContext.java

Author: jboynes
Date: Fri Feb  2 10:24:38 2007
New Revision: 502683

URL: http://svn.apache.org/viewvc?view=rev&rev=502683
Log:
change return type of RequestContext#getServiceReference

Modified:
    incubator/tuscany/java/spec/sca-api-r1.0/src/main/java/org/osoa/sca/RequestContext.java

Modified: incubator/tuscany/java/spec/sca-api-r1.0/src/main/java/org/osoa/sca/RequestContext.java
URL: http://svn.apache.org/viewvc/incubator/tuscany/java/spec/sca-api-r1.0/src/main/java/org/osoa/sca/RequestContext.java?view=diff&rev=502683&r1=502682&r2=502683
==============================================================================
--- incubator/tuscany/java/spec/sca-api-r1.0/src/main/java/org/osoa/sca/RequestContext.java (original)
+++ incubator/tuscany/java/spec/sca-api-r1.0/src/main/java/org/osoa/sca/RequestContext.java Fri Feb  2 10:24:38 2007
@@ -41,9 +41,9 @@
     String getServiceName();
 
     /**
      * Returns a ServiceReference to the service that was invoked.
      *
      * @return a ServiceReference to the service that was invoked
      */
-    <B> ServiceReference<B> getServiceReference();
+    <B, R extends CallableReference<B>> R getServiceReference();
 }



---------------------------------------------------------------------
@@ -41,9 +41,9 @@
 
     /**
-     * Returns a ServiceReference to the service that was invoked.
+     * Returns a CallableReference to the service or callback that was invoked.
      *
@@ -41,9 +41,9 @@
      *
-     * @return a ServiceReference to the service that was invoked
+     * @return a CallableReference to the service or callback that was invoked
      */
To unsubscribe, e-mail: tuscany-commits-unsubscribe@ws.apache.org
For additional commands, e-mail: tuscany-commits-help@ws.apache.org